import os.path
import pickle
from sklearn.preprocessing import StandardScaler
from sklearn.neural_network import MLPClassifier

from spotifymoods.constants import AUDIO_FEATURES


def train(data, trained_output, scaled_output):
    nn = None
    scaler = None

    x = data[AUDIO_FEATURES]
    y = data['mood']

    if os.path.isfile(trained_output) and os.path.isfile(scaled_output):
        with open(trained_output, 'rb') as f:
            nn = pickle.load(f)

        with open(scaled_output, 'rb') as f:
            scaler = pickle.load(f)

        scaled = scaler.partial_fit(x).transform(x)
        nn.partial_fit(scaled, y)
    else:
        scaler = StandardScaler()
        nn = MLPClassifier(hidden_layer_sizes=8, max_iter=15000, alpha=1.0)

        scaled = scaler.fit_transform(x)
        nn.fit(scaled, y)

    with open(trained_output, 'wb') as f:
        pickle.dump(nn, f)

    with open(scaled_output, 'wb') as f:
        pickle.dump(scaler, f)



import pickle
import pandas as pd

from spotifymoods.constants import AUDIO_FEATURES


def predict(data, trained_path, scaled_path):
    x = data[AUDIO_FEATURES]

    with open(trained_path, 'rb') as f:
        nn = pickle.load(f)

    with open(scaled_path, 'rb') as f:
        scaler = pickle.load(f)

    transformed = scaler.transform(x)
    y = nn.predict(transformed)
    result = pd.DataFrame(data['id'])
    result[AUDIO_FEATURES] = x
    result['mood'] = y

    return result



from pathlib import Path
from setuptools import setup, find_packages

VERSION = '0.0.5'
DESCRIPTION = 'A simple ML model to classify Spotify tracks using audio features.'
this_directory = Path(__file__).parent
LONG_DESCRIPTION = (this_directory / 'README.md').read_text()

setup(
    name='spotifymoods',
    version=VERSION,
    author='Ammar Oker',
    author_email='<oker.ammar@gmail.com>',
    url='https://github.com/ammar-oker/spotifymoods',
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=['pandas', 'scikit_learn'],
    keywords=['spotify', 'machine learning', 'spotify moods', 'spotify emotions'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Education',
        'Programming Language :: Python :: 3',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
    ]
)
